-- Name: EAS_AnimalsMenuExtension
-- Author: Chissel

EAS_AnimalsMenuExtension = {}

function EAS_AnimalsMenuExtension:init()
    g_easUtils:logText("EAS_AnimalsMenuExtension created")

    InGameMenuAnimalsFrame.onFrameOpen = Utils.appendedFunction(InGameMenuAnimalsFrame.onFrameOpen, EAS_AnimalsMenuExtension.onFrameOpen)
    InGameMenuAnimalsFrame.onFrameClose = Utils.appendedFunction(InGameMenuAnimalsFrame.onFrameClose, EAS_AnimalsMenuExtension.onFrameClose)
    InGameMenuAnimalsFrame.onListSelectionChanged = Utils.appendedFunction(InGameMenuAnimalsFrame.onListSelectionChanged, EAS_AnimalsMenuExtension.onListSelectionChanged)
end

function EAS_AnimalsMenuExtension:onFrameOpen()
    local selectedHusbandry = g_currentMission.inGameMenu.pageAnimals.selectedHusbandry

    if selectedHusbandry == nil then
        return
    end

    g_easUtils:logText("onFrameOpen")
    local inGameMenu = g_currentMission.inGameMenu

    if inGameMenu.overcrowdingButton == nil then
        local parent = inGameMenu.menuButton[1].parent
		inGameMenu.overcrowdingButton = inGameMenu.menuButton[1]:clone(parent)
		inGameMenu.overcrowdingButton.onClickCallback = EAS_AnimalsMenuExtension.onOvercrowdingButtonClicked
		inGameMenu.overcrowdingButton:setText(g_i18n:getText("EAS_AllowOvercrowding"))
		inGameMenu.overcrowdingButton:setInputAction("MENU_EXTRA_1")
        inGameMenu.menuButton[1].parent:addElement(inGameMenu.overcrowdingButton)
	end

    EAS_AnimalsMenuExtension.updateOvercrowdingButton(inGameMenu.overcrowdingButton, selectedHusbandry.allowOvercrowding)
end

function EAS_AnimalsMenuExtension:onFrameClose()
    g_easUtils:logText("onFrameClose")

    local inGameMenu = g_currentMission.inGameMenu

    if inGameMenu.overcrowdingButton ~= nil then
        inGameMenu.overcrowdingButton:unlinkElement()
        inGameMenu.overcrowdingButton:delete()
        inGameMenu.overcrowdingButton = nil
    end
end

function EAS_AnimalsMenuExtension:onListSelectionChanged()
    g_easUtils:logText("onListSelectionChanged")

    local inGameMenu = g_currentMission.inGameMenu
    if inGameMenu.overcrowdingButton ~= nil then
        local selectedHusbandry = g_currentMission.inGameMenu.pageAnimals.selectedHusbandry
        EAS_AnimalsMenuExtension.updateOvercrowdingButton(inGameMenu.overcrowdingButton, selectedHusbandry.allowOvercrowding)
    end
end

function EAS_AnimalsMenuExtension.onOvercrowdingButtonClicked(dialog)
    local selectedHusbandry = g_currentMission.inGameMenu.pageAnimals.selectedHusbandry
    if selectedHusbandry.allowOvercrowding then
        selectedHusbandry.allowOvercrowding = false
    else
        selectedHusbandry.allowOvercrowding = true
    end
    g_easUtils:logText("Update overcrowding state")

    if dialog.overcrowdingButton ~= nil then
        EAS_AnimalsMenuExtension.updateOvercrowdingButton(dialog.overcrowdingButton, selectedHusbandry.allowOvercrowding)
        g_easUtils:logText("Update overcrowding button")
    end
end

function EAS_AnimalsMenuExtension.updateOvercrowdingButton(button, allowOvercrowding)
    if allowOvercrowding then
        button:setText(g_i18n:getText("EAS_PreventOvercrowding"))
    else
        button:setText(g_i18n:getText("EAS_AllowOvercrowding"))
    end
end