-- Name: EAS_Utils
-- Author: Chissel

local myName = "EAS_Utils"

EAS_Utils = {}
EAS_Utils.__index = EAS_Utils
EAS_Utils.DebuggerMode = true
EAS_Utils.Settings = {}

setmetatable(EAS_Utils, {
  __call = function (cls, ...)
  local self = setmetatable({}, cls)

  self:new(...)

  return self
  end,
})

function EAS_Utils:new()
    if EAS_Utils.DebuggerMode then
       EAS_Utils:logText("Debug mode is active")
    end
end

function EAS_Utils.loadXml()
	local path = g_currentModDirectory .. "settings.xml"
	local key = "EnhancedAnimalSystem.Settings"
	local xmlFileId = loadXMLFile("EAS_Utils", path)

	EAS_Utils.Settings.SellingPricePercentage = getXMLFloat(xmlFileId, key.."#SellingPricePercentage")
	EAS_Utils.Settings.MaxOvercrowdingPercentage = getXMLFloat(xmlFileId, key.."#MaxOvercrowdingPercentage")
	EAS_Utils.Settings.AnimalDiedPercentage = getXMLInt(xmlFileId, key.."#AnimalDiedPercentage")
	
	EAS_Utils.Settings.MinPiglets = getXMLInt(xmlFileId, key.."#MinPiglets")
	EAS_Utils.Settings.MaxPiglets = getXMLInt(xmlFileId, key.."#MaxPiglets")
	EAS_Utils.Settings.PigMaxAge = getXMLInt(xmlFileId, key.."#PigMaxAge")

	EAS_Utils.Settings.MinCalfs = getXMLInt(xmlFileId, key.."#MinCalfs")
	EAS_Utils.Settings.MaxCalfs = getXMLInt(xmlFileId, key.."#MaxCalfs")
	EAS_Utils.Settings.CowMaxAge = getXMLInt(xmlFileId, key.."#CowMaxAge")

	EAS_Utils.Settings.MinFoals = getXMLInt(xmlFileId, key.."#MinFoals")
	EAS_Utils.Settings.MaxFoals = getXMLInt(xmlFileId, key.."#MaxFoals")
	EAS_Utils.Settings.HorseMaxAge = getXMLInt(xmlFileId, key.."#HorseMaxAge")

	EAS_Utils.Settings.MinLambs = getXMLInt(xmlFileId, key.."#MinLambs")
	EAS_Utils.Settings.MaxLambs = getXMLInt(xmlFileId, key.."#MaxLambs")
	EAS_Utils.Settings.SheepMaxAge = getXMLInt(xmlFileId, key.."#SheepMaxAge")

	EAS_Utils.Settings.MinChickens = getXMLInt(xmlFileId, key.."#MinChickens")
	EAS_Utils.Settings.MaxChickens = getXMLInt(xmlFileId, key.."#MaxChickens")
	EAS_Utils.Settings.ChickenMaxAge = getXMLInt(xmlFileId, key.."#ChickenMaxAge")

	local pigletsProbabilities = EAS_Utils.sliceByKomma(getXMLString(xmlFileId, key.."#PigletsProbabilities"))
    EAS_Utils.Settings.PigletProbabilities = EAS_Utils.createProbabilityTable(pigletsProbabilities, EAS_Utils.Settings.MinPiglets)
	local calfProbabilities = EAS_Utils.sliceByKomma(getXMLString(xmlFileId, key.."#CalfProbabilities"))
    EAS_Utils.Settings.CalfProbabilities = EAS_Utils.createProbabilityTable(calfProbabilities, EAS_Utils.Settings.MinCalfs)
	local foalProbabilities = EAS_Utils.sliceByKomma(getXMLString(xmlFileId, key.."#FoalProbabilities"))
    EAS_Utils.Settings.FoalProbabilities = EAS_Utils.createProbabilityTable(foalProbabilities, EAS_Utils.Settings.MinFoals)
	local lambProbabilities = EAS_Utils.sliceByKomma(getXMLString(xmlFileId, key.."#LambProbabilities"))
    EAS_Utils.Settings.LambProbabilities = EAS_Utils.createProbabilityTable(lambProbabilities, EAS_Utils.Settings.MinLambs)
	local chickenProbabilities =  EAS_Utils.sliceByKomma(getXMLString(xmlFileId, key.."#ChickenProbabilities"))
    EAS_Utils.Settings.ChickenProbabilities = EAS_Utils.createProbabilityTable(chickenProbabilities, EAS_Utils.Settings.MinChickens)
	
	if EAS_Utils.DebuggerMode then
        EAS_Utils:logText("Load settings xml")
		
		for k,v in pairs(EAS_Utils.Settings) do
			print(tostring(k)..": "..tostring(v))
		end
	end

    return EAS_Utils.Settings
end

function EAS_Utils.createProbabilityTable(values, minValue)
    local probabilities = {}
    for index, value in pairs(values) do
        EAS_Utils.insertXTimes(minValue + (index - 1), value, probabilities)
    end
    return probabilities
end

function EAS_Utils.insertXTimes(value, times, mutableTable)
    for i=1, times do
        table.insert(mutableTable, value)
    end
end

function EAS_Utils.sliceByKomma(text)
    local values = {}
    for value in text:gmatch('[^,%s]+') do
        table.insert(values, value)
    end
    return values
end

function EAS_Utils:hasItem(array, item)
    for _, value in ipairs(array) do
        if value == item then
            return true
        end
    end

    return false
end

function EAS_Utils:removeItemFromTable(item, array)
    for index, value in ipairs(array) do
        if value == item then
            table.remove(array, index)
            break
        end
    end
end

function EAS_Utils:logText(text)
	if EAS_Utils.DebuggerMode then
        local prefix = "------------------------------------------------ EnhancedAnimalSystem ------------------------------------------------"
        print(prefix, text)
    end
end